Crate btsg_ft_factory

Crate btsg_ft_factory 

btsg-ft-factory

Serves as a factory that issues new fantokens on BitSong and returns their denom for use with the dao-voting-token-staked voting module contract.

Instantiation and execution are permissionless. All DAOs will use the same factory and execute Issue to create new fantokens through TokenInfo::Factory during voting module instantiation.

Modules

bitsong
contract
msg
state

Enums

ContractError